@@ -205,7 +205,11 @@ daviesGLM<-function(y, z, xreg, weights, offs, values=NULL, k, list.glm, alterna
     mf$formula<-update.formula(mf$formula,paste(seg.Z,collapse=".+"))
     formulaOrig<-formula(obj)
     if(class(obj)[1]=="segmented"){
-        if(!is.null(eval(obj$call$obj)$call$data)) mf$data <- eval(obj$call$obj)$call$data
+        #10/12/20. se segmented e' stato chiamato con un oggetto m (cioe m<-lm()), allora digitando eval(obj$call$obj)
+        #restituiva 'm' ottenuto dal comando di sopra.. match(c("formula",..
+        #sembra che mettendo eval(obj$call$obj, parent.frame()) o anche eval(obj$call$obj, envir=0) riesca ad ignorare 
+        #l'oggetto m che si trova nell'ambiente della funzione  
+        if(!is.null(eval(obj$call$obj, parent.frame())$call$data)) mf$data <- eval(obj$call$obj, parent.frame())$call$data
         mf$formula<-update.formula(mf$formula,paste("~.-",paste(obj$nameUV$V, collapse="-")))
         for(i in 1:length(obj$nameUV$U)) assign(obj$nameUV$U[i], obj$model[,obj$nameUV$U[i]], envir=parent.frame())
         formulaOrig<-update.formula(formulaOrig, paste("~.-",paste(obj$nameUV$V, collapse="-")))
@@ -234,7 +238,7 @@ daviesGLM<-function(y, z, xreg, weights, offs, values=NULL, k, list.glm, alterna
     if(is.null(values)) values<-seq(sort(Z)[2], sort(Z)[(n - 1)], length = k)
        #values<-seq(min(z), max(z), length=k+2)
        #values<-values[-c(1,length(values))]
-    if(class(obj)=="lm" || identical(class(obj),c("segmented","lm")) ) {
+    if(class(obj)[1]=="lm" || identical(class(obj),c("segmented","lm")) ) {
         if(n<=300) { 
           rr<-daviesLM(y=y, z=Z, xreg=XREG, weights=weights, 
         offs=offs, values=values, k=k, alternative=alternative)
