@@ -28,6 +28,9 @@ extract.psi<-function(lista){
       n<-nrow(Z)
       o0<-try(suppressWarnings(seg.Ar.fit(obj, XREG, Z, PSI, opz)), silent=TRUE)
       rangeZ <- apply(Z, 2, range) #serve sempre
+      alpha <- opz$alpha
+      limZ <- apply(Z, 2, quantile, names = FALSE, probs = c(alpha, 1 - alpha))
+      
       if(!is.list(o0)) {
           o0<- seg.Ar.fit(obj, XREG, Z, PSI, opz, return.all.sol=TRUE)
           o0<-extract.psi(o0)
@@ -41,7 +44,7 @@ extract.psi<-function(lista){
         } else {
           if(!nonParam) stop("the first fit failed and I cannot extract fitted values for the semipar boot")
           if(random) {
-            est.psi00<-est.psi0<-apply(rangeZ,2,function(r)runif(1,r[1],r[2]))
+            est.psi00<-est.psi0<-apply(limZ,2,function(r)runif(1,r[1],r[2]))
             PSI1 <- matrix(rep(est.psi0, rep(nrow(Z), length(est.psi0))), ncol = length(est.psi0))
             o0<-try(suppressWarnings(seg.Ar.fit(obj, Z, PSI1, opz1)), silent=TRUE)
             ss00<-o0$SumSquares.no.gap
@@ -61,9 +64,13 @@ extract.psi<-function(lista){
       #if(visualBoot) cat(0, " ", formatC(opz$dev0, 3, format = "f"),"", "(No breakpoint(s))", "\n")
       count.random<-0
       for(k in seq(n.boot)){
-        n.boot.rev<-4
-        if(length(na.omit(diff(all.selected.ss[1:n.boot.rev])))==(n.boot.rev-1) && all(round(diff(all.selected.ss[1:n.boot.rev]),6)==0)){
+        ##se gli *ultimi* n.boot.rev valori di ss sono uguali, cambia i psi...
+        n.boot.rev<- 3 #3 o 4?
+        diff.selected.ss <- rev(diff(na.omit(all.selected.ss)))
+        #if(length(na.omit(diff(all.selected.ss[1:n.boot.rev])))==(n.boot.rev-1) && all(round(diff(all.selected.ss[1:n.boot.rev]),6)==0)){
+        if(length(diff.selected.ss)>=(n.boot.rev-1) && all(round(diff.selected.ss[1:(n.boot.rev-1)],6)==0)){
           qpsi<-sapply(1:ncol(Z),function(i)mean(est.psi0[i]>=Z[,i]))
+          qpsi<-ifelse(abs(qpsi-.5)<.1,.8,qpsi)
           est.psi0<-sapply(1:ncol(Z),function(i)quantile(Z[,i],probs=1-qpsi[i],names=FALSE))
         }
         
@@ -81,14 +88,14 @@ extract.psi<-function(lista){
           if(is.list(o.boot)){
             all.est.psi.boot[k,]<-est.psi.boot<-o.boot$psi
             } else {
-            est.psi.boot<-apply(rangeZ,2,function(r)runif(1,r[1],r[2]))
+            est.psi.boot<-apply(limZ,2,function(r)runif(1,r[1],r[2]))
             }
           PSI <- matrix(rep(est.psi.boot, rep(nrow(Z), length(est.psi.boot))), ncol = length(est.psi.boot))
           #opz$h<-max(opz$h*.9, .2)
           opz$it.max<-opz$it.max+1
           o <- try(suppressWarnings(seg.Ar.fit(obj, XREG, Z.orig, PSI, opz, return.all.sol=TRUE)), silent=TRUE)
           if(!is.list(o) && random){
-              est.psi0<-apply(rangeZ,2,function(r) runif(1,r[1],r[2]))
+              est.psi0<-apply(limZ,2,function(r) runif(1,r[1],r[2]))
               PSI1 <- matrix(rep(est.psi0, rep(nrow(Z), length(est.psi0))), ncol = length(est.psi0))
               o <- try(suppressWarnings(seg.Ar.fit(obj, XREG, Z, PSI1, opz1)), silent=TRUE)
               count.random<-count.random+1
